function Pi=PlotFrequency(n0,ARatio, maxf, maxn)
% This function plots the theoretical frequency distribution PI(n)*A/A_0 for a species with n0 individuals
% in A0. This shows the expected number of plots with n individuals.
% ARatio=A/A0


% n-vector for plotting
n=0:n0;
Pi=zeros(1,n0+1);

% Uses the simple result for A=A0/2 
if ARatio==0.5
    
    % Probability distribution is flat
    Pi(:,:)=1/(n0+1);
    
% Calculates the probability of presence from Equation 7.48-50 in the book.
% These equations show how to solve for Pi(n) for any abundance n0 and in
% any A<A0.
else
    options = optimset('Display','off','TolX',1e-8,'TolFun',1e-8);
    guess=0.06;
        % The function used to find lambdaPi (or x=e^(-lambdaPi)) is given
        % below
        x=fsolve(@(x)fun(x,n0,ARatio),guess,options);
        
        for i=0:n0 
        % For each n the probability is given by
        Pi(i+1)=(1-x)*x^i/(1-x^(n0+1));
        end
       
    
    
end
Pi=Pi/ARatio;
%fprintf(['PI(0)=' num2str(Pi(1)) ' for n0=' num2str(n0) '\n']);
figure('Name', ['PI(n) for n0=' num2str(n0) ' for A/A0=' num2str(ARatio)])
%plot(n,Pi);
grid on;
bar(n,Pi,'hist');
%hist(Pi,0:n0);
xlabel('n');
ylabel(['\pi' '(n)A_0/A']);
axis([0 maxn 0 maxf]);
%set(gca,'XData',XData(0:1:maxn));
sum(Pi);
end


% Function for calculating x=e^(-lambdaPi)
function F=fun(x,n0,ARatio)
    F=x/(1-x)-(n0+1)*x^(n0+1)/(1-x^(n0+1))-n0*ARatio;
end