function presenceMatrix = Presence(n0Vect, ARatio)
% Function calculates a matrix of presence (value 1) and absence (value 0).
% Each row is a different species, and each column is a different trial.
% n0Vect is a vector where each element is the abundance of one of the
% species. length(n0Vect)=S0 and sum(n0Vect)=N0.
% ARatio=A/A0

trials= 256*4000;

% PiPres is a column vector with the probabilities of presence in A<A0 for
% each of the species in n0Vect.
PiPresent=PiPres(n0Vect,ARatio);

% This command repeats the vector PiPresent which contains the
% probabilities that the species' are present. The element number in
% PiPresent corresponds to the species with the abundance in the same
% element number in n0Vect. PiPresent is a column vector
ProbabilityMatrix=repmat(PiPresent,1,trials);

% Create a random matrix of numbers between 0 and 1 with the same dimension 
% as ProbabilityMatrix
RandomMatrix=rand(length(n0Vect),trials);

% This command compares the random matrix with the probability matrix. When
% the random number is within the probability of a species being present
% (that is, the random number is smaller than the probability) the value is
% set to one. Each column corresponds to one trial (where the row number is
% a different species). A 1 means that this species is present, a 0 means
% that it is not.
presenceMatrix=RandomMatrix<ProbabilityMatrix;
